@@ -1,37 +1,37 @@
 $VAR1 = {
+          'scriptAlias' => 'cgi-bin',
+          'floodtime' => 10,
           'cgi' => {
-                     'alias' => 'cgi-bin',
-                     'style' => 'mysql',
-                     'serverName' => 'http://localhost',
-                     'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs',
                      'bin' => '/var/www/cgi-bin',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'expires' => '+1y',
+                     'cookiePath' => '/',
+                     'serverName' => 'http://localhost',
                      'title' => 'MySQL::Admin',
-                     'cookiePath' => '/'
+                     'style' => 'mysql',
+                     'alias' => 'cgi-bin'
                    },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'database' => {
-                          'password' => 'wertvoll',
-                          'CurrentHost' => 'localhost',
+                          'name' => 'LZE',
+                          'password' => 'keinz',
+                          'CurrentUser' => 'root',
                           'host' => 'localhost',
                           'CurrentDb' => 'LZE',
-                          'CurrentPass' => 'wertvoll',
+                          'CurrentHost' => 'localhost',
                           'user' => 'root',
-                          'CurrentUser' => 'root',
-                          'name' => 'LZE'
+                          'CurrentPass' => 'keinz'
                         },
+          'language' => 'en',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'version' => '0.72',
           'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
                        'name' => 'Lindner',
                        'firstname' => 'Dirk',
-                       'password' => 'testpass'
+                       'password' => 'testpass',
+                       'email' => 'dirk.lze@gmail.com'
                      },
-          'language' => 'en',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'floodtime' => 10,
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'scriptAlias' => 'cgi-bin',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'version' => '0.71'
+          'session' => '/var/www/cgi-bin/config/session.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
