@@ -8,7 +8,7 @@ CREATE TABLE `actions` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=149 DEFAULT CHARSET=utf8;
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','Login','0','tables','main','147');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables','main','147');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables','AddFulltext','62');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables','AnalyzeTable','63');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','tables','AddPrimaryKey','64');
@@ -79,14 +79,14 @@ INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values(
 
 CREATE TABLE `box` (
   `file` varchar(100) NOT NULL DEFAULT '',
-  `position` varchar(8) NOT NULL DEFAULT 'left',
   `right` int(1) NOT NULL DEFAULT '0',
   `name` varchar(100) NOT NULL DEFAULT '',
+  `outId` varchar(100) NOT NULL DEFAULT 'content',
   `id` int(11) NOT NULL AUTO_INCREMENT,
-  `dynamic` varchar(10) DEFAULT NULL,
   PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
-INSERT INTO `box` (`file`,`position`,`right`,`name`,`id`,`dynamic`) values('tables.pl','menuBar','5','database','10','right');
+) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
+INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
+INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');
 CREATE TABLE `exploit` (
   `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `referer` text NOT NULL,
@@ -97,7 +97,7 @@ CREATE TABLE `exploit` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `id` (`id`),
   FULLTEXT KEY `remote_addr` (`remote_addr`)
-) ENGINE=MyISAM AUTO_INCREMENT=40 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 CREATE TABLE `querys` (
   `title` varchar(100) NOT NULL DEFAULT '',
   `description` text NOT NULL,
@@ -343,5 +343,5 @@ CREATE TABLE `users` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
-INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','hghsdf7','dd','1');
-INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('fe7374a18d3f8ca9547e49aa39a2dd67','admin','5','7856efbdf0d8bfc10933add28a2f62e4','127.0.0.1','2');
+INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
+INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('fe7374a18d3f8ca9547e49aa39a2dd67','admin','5','3cd93fcddf701b48bf4b1766c856a489','127.0.0.1','2');
\ No newline at end of file
