@@ -8,21 +8,21 @@ function alert(txt){
 	visible('popup');
         setText('popupContent','<div align="center">'+txt+'<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
 	var node = $("confirmButton");
-	node.addEventListener ('click', function (evt) {
+	node.addEventListener('click', function (evt){
 	  hide('popup');
 	});
 }
 function confirm2(txt,sub,arg,arg2,arg3){
 	visible('popup');
 	var sleep = true;
-        setText('popupContent',txt+'<div align="right"><input type="submit" name="cancelButton" id="cancelButton" value="Cancel"/>&#160;<input  type="submit" id="confirmButton" value="Ok"/></div>');
+        setText('popupContent','<b>'+txt+'</b><div align="right" style="padding:0.4em;"><input type="submit" name="cancelButton" id="cancelButton" value="Cancel"/>&#160;<input  type="submit" id="confirmButton" value="Ok"/></div>');
 	var node = $("confirmButton");
-	node.addEventListener ('click', function (evt) {
+	node.addEventListener ('click',function (evt){
 	  hide('popup');    
 	  sub(arg,arg2,arg3);
 	});
 	var node2 = $("cancelButton");
-	node2.addEventListener ('click', function (evt) {
+	node2.addEventListener ('click',function (evt){
 	  hide('popup');
 	  evt.stopPropagation();
 	});
@@ -121,9 +121,9 @@ function loadPage(inXml,inXsl,outId,tabId,title){
   	}
 	if(tabId && title)
 		setCurrentTab(tabId,title);
+	
+	disableOutputEscaping('content');
 
-	if (navigator.userAgent.indexOf("Firefox")!=-1 && inXml.indexOf(".xml") ==-1)
-		$('content').innerHTML = $('content').textContent;
 }
 
 window.onerror = logError;
@@ -216,7 +216,7 @@ function showPopup(id,hideCloseButton){
 	evalId(id);
 }
 function closePopup(){
-	setText(tmpID,tmpTxt);
+	setText(tmpID,tmpTxt);	
         hide('popup');
 	$('popupContent1').style.left='25%';
 	$('popupContent1').style.width='50%';
@@ -229,11 +229,17 @@ function submitForm(node,tabId,tabTitle){
 	  for(var i =0; i < node.elements.length;i++){
 	    if(node.elements[i].type == 'checkbox' || node.elements[i].type == 'radio'){
 		    if(node.elements[i].checked)
-			url += node.elements[i].name+"="+node.elements[i].value+"&"; 
+			url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
 	    }else if(node.elements[i].name == 'submit'){
-	      url += node.elements[i].name+"="+act+"&";
+	      url += node.elements[i].name+"="+encodeURIComponent(act)+"&";
+	    }else if(node.elements[i].type == 'select-multiple'){
+	       for (var j=0, len=node.elements[i].options.length; j<len; j++) {
+		var  opt = node.elements[i].options[j];
+		if ( opt.selected )
+		      url += node.elements[i].name +"="+ encodeURIComponent(node.elements[i].options[j].value)+"&";
+		}
 	    }else{
-	      url += node.elements[i].name+"="+node.elements[i].value+"&"; 
+	      url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
 	    }
 	  }
 	  requestURI(url,tabId,tabTitle);
@@ -242,7 +248,7 @@ function submitForm(node,tabId,tabTitle){
 var http_request = false;
 var oldpage;
 function requestURI(url,id,txt,bHistory){
-	hide('popup');
+	closePopup();
 	bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
 	if(bHistory)
 	  history.pushState(null, '','?'+url);
@@ -310,12 +316,18 @@ function setContent() {
 		setCurrentTab(currentId, currentTxt);
 	  }
 	  var closeButton = $("closeButton");
-	  if(!document.cookie.match('sid') ){
+	  if(!document.cookie.match('sid') || document.cookie.match('sid=123') ){
 	    showPopup('login',true);
 	    evalId('popupContent');
 	  }else{
 	    closeButton.addEventListener ('click',closePopup);
 	  }
+	  hide('toolbarcontent2');
+	  hide('toolbarcontent');
+	  if($('toolbar'))
+	    $('toolbar').classList.add('closed');
+	  if($('toolbar2'))
+	    $('toolbar2').classList.add('closed');
         }
 }
 function evalId(id){
@@ -341,10 +353,9 @@ function loadHistory(){
 	rxObj2.exec(window.location.search);
 	var uri = RegExp.$1;
 	if(uri && action)
-	  requestURI('cgi-bin/mysql.pl'+uri,action,translate(action),false);
+	  requestURI('cgi-bin/mysql.pl'+uri,action,action,false);
 	else
-	  requestURI('cgi-bin/mysql.pl?action=showDatabases','showDatabases','Datenbanken');
-// 	alert();
+	  requestURI('cgi-bin/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
 	return true;
 }
 function translate(string){
@@ -373,3 +384,87 @@ if (navigator.userAgent.indexOf("Firefox")!=-1)
 function $(id){
     return document.getElementById(id);
 }
+var autocomplete = new Array("select","from","where","insert","set","update");
+function Autocomplete(evt){
+  if (evt.which == 8 ||evt.which == 16||  evt.which === 37 || evt.which === 38 ||evt.which === 39 || evt.which === 39 || evt.which === 40  )
+    return;
+    var offset = 3;
+    while($("sqlEdit").selectionStart-offset >= 0 && offset < 10){//todo port to IE
+	  var  match = ''
+	  if( $("sqlEdit").value.substr($("sqlEdit").selectionStart-offset-1, 1) ==' ' ||$("sqlEdit").value.substr($("sqlEdit").selectionStart-offset-1, 1).search(new RegExp("\\b")) == -1|| $("sqlEdit").selectionStart-offset == 0){
+	      match = $("sqlEdit").value.substr($("sqlEdit").selectionStart-offset, offset);
+	  }
+	  var i = 0;
+	  var j = autocomplete.length;
+	  while( i < autocomplete.length){
+		if(match.toLowerCase() == autocomplete[i].substr(0,offset)){
+		  var selectionStart = $("sqlEdit").selectionStart;
+		  var before = $("sqlEdit").value.substr(0,selectionStart-offset);
+		  var behind = $("sqlEdit").value.substr(selectionStart,$("sqlEdit").value.length);
+		  $("sqlEdit").value = before+autocomplete[i]+behind;
+		  $("sqlEdit").selectionStart = selectionStart;
+		  $("sqlEdit").selectionEnd   = selectionStart+autocomplete[i].length-offset;
+		  break;
+		}
+		i++;
+	    }
+      offset++;
+      }
+}
+function selKeyword(id){
+  for(var i= 0; i<  $(id).options.length;i++ )
+      autocomplete.push( $(id).options[i].value.toLowerCase());
+}
+var uno = true;
+function showSQLEditor(){
+  $('popupContent1').style.left='5%';
+  $('popupContent1').style.width='90%';
+  showPopup('SqlEditor');
+  $("sqlEdit").addEventListener ('keyup', Autocomplete);
+  if(uno){
+    selKeyword('selKeyword');
+    selKeyword('tablelist');
+    for(var i= 0; i<  $('tablelist').options.length;i++ )
+	selKeyword($('tablelist').options[i].value);
+  }
+  uno = false;
+}
+function insertAtCursorPosition(txt){
+       var textarea  = document.getElementById('sqlEdit');
+       if(typeof document.selection != 'undefined'){ //IE6
+              range = document.selection.createRange();
+              var txt = range.text;
+	      range.text = txt;
+	      range.moveStart('character', txt.length );
+              range.select();
+       }else if(textarea.selectionStart &&(textarea.selectionEnd == textarea.selectionStart)){//insert at gecko
+              var ia = textarea.selectionStart;
+              var a = textarea.value.substring(0,ia);
+              var b = textarea.value.substring(ia,textarea.value.length);
+              textarea.value = a+txt+b;
+       }else{
+             textarea.value += txt;	
+       }
+}
+
+function toolbar(){
+    displayTree('toolbar2');  
+    displayTree('toolbar'); 
+}
+
+function displayTree(id){
+  var entry = $(id);
+  if(entry && entry.firstChild){
+    if(entry.firstChild.style.display == 'none'){
+      bToolbar = true;
+      entry.classList.remove('closed');
+        if(entry.firstChild)
+		entry.firstChild.style.display ='';
+    }else{
+      entry.classList.add('closed');
+      bToolbar = false;
+        if(entry.firstChild)
+		entry.firstChild.style.display ='none';
+    }
+  }
+}
\ No newline at end of file
