@@ -54,7 +54,7 @@ use vars qw(
 );
 @MySQL::Admin::GUI::EXPORT  = qw(ContentHeader Body ChangeDb Unique);
 @ISA                        = qw(Exporter MySQL::Admin);
-$MySQL::Admin::GUI::VERSION = '0.71';
+$MySQL::Admin::GUI::VERSION = '0.72';
 $m_bMod_perl                = ( $ENV{MOD_PERL} ) ? 1 : 0;
 local $^W = 0;
 $m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
@@ -131,12 +131,16 @@ sub ContentHeader {
     }
     my $cookiepath = $m_hrSettings->{cgi}{cookiePath};
 
-    undef $m_sSid;
+    $m_sSid = cookie( -name => 'sid' ) ? cookie( -name => 'sid' ) : '123';
 
-    if ( $m_sAction eq 'logout' ) {
+  $m_sUser =
+      defined $m_oDatabase->getName($m_sSid)
+      ? $m_oDatabase->getName($m_sSid)
+      : 'guest';
+    if ( $m_sAction eq 'logout' or  ($m_sAction ne 'login' and $m_sUser eq 'guest') ) {
         my $cookie = cookie(
             -name    => 'sid',
-            -value   => "",
+            -value   => '',
             -expires => '-1d',
             -path    => "$cookiepath"
         );
@@ -205,10 +209,9 @@ sub ContentHeader {
                 -cookie  => [@m_aCookies]
             );
         }
-        $m_sAction = 'showDatabases';
+        $m_sAction = 'ShowDatabases';
     }
     else {
-        $m_sSid = cookie( -name => 'sid' ) ? cookie( -name => 'sid' ) : '123';
         print header(
             -type    => 'text/xml',
             -charset => 'UTF-8',
@@ -255,7 +258,7 @@ sub Body {
 
     if ( defined $m_hrAct->{box} ) {
 
-        my @boxes = split /;/, $m_hrAct->{box};
+        my @boxes = split / /, $m_hrAct->{box};
         foreach my $box (@boxes) {
             $m_sContent = "";
             my $bx = $m_oDatabase->fetch_hashref(
@@ -267,7 +270,7 @@ sub Body {
             $m_sAjax .= "<output id=\"errorMessage\"><![CDATA[$@]]></output>"
               if ($@);
             $m_sAjax .=
-                "<output id=\"$bx->{position}\"><![CDATA["
+                "<output id=\"$bx->{outId}\"><![CDATA["
               . $m_sContent
               . ']]></output>'
               if $m_sContent;
